/**
 * generische ADT-Klasse Menge (nur ein Ausschnitt)
 * 
 */
class Menge<T> {

	private Object[] werte;
	private int next;

	public Menge(int maxSize) {
		this.werte = new Object[maxSize];
		this.next = 0;
	}

	@SuppressWarnings("unchecked")
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (this.getClass() != obj.getClass()) {
			return false;
		}
		Menge<T> menge = (Menge<T>) obj;
		if (this.next != menge.next) {
			return false;
		}
		for (int i = 0; i < this.next; i++) {
			boolean enthalten = false;
			for (int j = 0; j < this.next; j++) {
				if (menge.werte[j].equals(this.werte[i])) {
					enthalten = true;
				}
			}
			if (!enthalten) {
				return false;
			}
		}
		return true;
	}

	@Override
	public String toString() {
		String str = "[";
		for (int i = 0; i < this.next - 1; i++) {
			str += this.werte[i] + ", ";
		}
		if (this.next - 1 >= 0) {
			str += this.werte[this.next - 1];
		}
		str += "]";
		return str;
	}

	public boolean istLeer() {
		return this.next == 0;
	}

	public boolean istVoll() {
		return this.next == this.werte.length;
	}

	public boolean istEnthalten(Object elem) {
		for (int i = 0; i < this.next; i++) {
			if (this.werte[i].equals(elem)) {
				return true;
			}
		}
		return false;
	}

	public boolean hinzufuegen(Object elem) {
		if (!this.istVoll() && !this.istEnthalten(elem)) {
			this.werte[this.next] = elem;
			this.next++;
			return true;
		} else {
			return false;
		}
	}

	public static <T> Menge<T> schnittmenge(Menge<T> m1, Menge<T> m2) {
		Menge<T> menge = new Menge<T>(Math.min(m1.werte.length, m2.werte.length));
		for (int i = 0; i < m1.next; i++) {
			for (int j = 0; j < m2.next; j++) {
				if (m1.werte[i].equals(m2.werte[j])) {
					menge.hinzufuegen(m1.werte[i]);
				}
			}
		}
		return menge;
	}

	public static <T> Menge<T> vereinigung(Menge<T> m1, Menge<T> m2) {
		Menge<T> menge = new Menge<T>(m1.werte.length + m2.werte.length);
		for (int i = 0; i < m1.next; i++) {
			menge.hinzufuegen(m1.werte[i]);
		}
		for (int i = 0; i < m2.next; i++) {
			menge.hinzufuegen(m2.werte[i]);
		}
		return menge;
	}
}

public class UE23Aufgabe1 {

	// kleines Testprogramm (nur ein Ausschnitt)
	public static void main(String[] args) {
		Menge<Integer> m1 = new Menge<Integer>(10);
		m1.hinzufuegen(2);
		m1.hinzufuegen(3);
		m1.hinzufuegen(2);
		System.out.println(m1);

		Menge<Integer> m2 = new Menge<Integer>(5);
		m2.hinzufuegen(1);
		m2.hinzufuegen(3);
		m2.hinzufuegen(5);
		System.out.println(m2);

		Menge<Integer> m3 = Menge.schnittmenge(m1, m2);
		System.out.println(m3);

		Menge<Integer> m4 = Menge.vereinigung(m1, m2);
		System.out.println(m4);
	}

}
